@@ -59,6 +59,7 @@ namespace {
   static const uint IMDB_MAX_RESULTS = 20;
 }
 
+using namespace Tellico;
 using Tellico::Fetch::IMDBFetcher;
 
 QRegExp* IMDBFetcher::s_tagRx = 0;
@@ -96,10 +97,6 @@ IMDBFetcher::IMDBFetcher(QObject* parent_) : Fetcher(parent_),
 IMDBFetcher::~IMDBFetcher() {
 }
 
-QString IMDBFetcher::defaultName() {
-  return i18n("Internet Movie Database");
-}
-
 QString IMDBFetcher::source() const {
   return m_name.isEmpty() ? defaultName() : m_name;
 }
@@ -115,7 +112,6 @@ void IMDBFetcher::readConfigHook(const KConfigGroup& config_) {
   }
   m_numCast = config_.readEntry("Max Cast", 10);
   m_fetchImages = config_.readEntry("Fetch Images", true);
-  m_fields = config_.readEntry("Custom Fields", QStringList());
 }
 
 // multiple values not supported
@@ -631,7 +627,7 @@ void IMDBFetcher::parseMultipleNameResults() {
   // do not stop() here
 }
 
-Tellico::Data::EntryPtr IMDBFetcher::fetchEntry(uint uid_) {
+Tellico::Data::EntryPtr IMDBFetcher::fetchEntryHook(uint uid_) {
   // if we already grabbed this one, then just pull it out of the dict
   Data::EntryPtr entry = m_entries[uid_];
   if(entry) {
@@ -707,7 +703,7 @@ Tellico::Data::EntryPtr IMDBFetcher::parseEntry(const QString& str_) {
   }
 
   const QString imdb = QLatin1String("imdb");
-  if(!coll->hasField(imdb) && m_fields.indexOf(imdb) > -1) {
+  if(!coll->hasField(imdb) && allOptionalFields().contains(imdb)) {
     Data::FieldPtr field(new Data::Field(imdb, i18n("IMDb Link"), Data::Field::URL));
     field->setCategory(i18n("General"));
     coll->addField(field);
@@ -762,7 +758,7 @@ void IMDBFetcher::doAspectRatio(const QString& str_, Tellico::Data::EntryPtr ent
 }
 
 void IMDBFetcher::doAlsoKnownAs(const QString& str_, Tellico::Data::EntryPtr entry_) {
-  if(m_fields.indexOf(QLatin1String("alttitle")) == -1) {
+  if(!allOptionalFields().contains(QLatin1String("alttitle"))) {
     return;
   }
 
@@ -980,7 +976,7 @@ void IMDBFetcher::doCast(const QString& str_, Tellico::Data::EntryPtr entry_, co
 }
 
 void IMDBFetcher::doRating(const QString& str_, Tellico::Data::EntryPtr entry_) {
-  if(m_fields.indexOf(QLatin1String("imdb-rating")) == -1) {
+  if(!allOptionalFields().contains(QLatin1String("imdb-rating"))) {
     return;
   }
 
@@ -1111,7 +1107,7 @@ void IMDBFetcher::doLists(const QString& str_, Tellico::Data::EntryPtr entry_) {
 
     // now add new field for all certifications
     const QString allc = QLatin1String("allcertification");
-    if(m_fields.indexOf(allc) > -1) {
+    if(allOptionalFields().contains(allc)) {
       Data::FieldPtr f = entry_->collection()->fieldByName(allc);
       if(!f) {
         f = new Data::Field(allc, i18n("Certifications"), Data::Field::Table);
@@ -1159,6 +1155,23 @@ Tellico::Fetch::FetchRequest IMDBFetcher::updateRequest(Data::EntryPtr entry_) {
   return FetchRequest();
 }
 
+QString IMDBFetcher::defaultName() {
+  return i18n("Internet Movie Database");
+}
+
+QString IMDBFetcher::defaultIcon() {
+  return favIcon("http://imdb.com");
+}
+//static
+Tellico::StringHash IMDBFetcher::allOptionalFields() {
+  StringHash hash;
+  hash[QLatin1String("imdb")]             = i18n("IMDb Link");
+  hash[QLatin1String("imdb-rating")]      = i18n("IMDb Rating");
+  hash[QLatin1String("alttitle")]         = i18n("Alternative Titles");
+  hash[QLatin1String("allcertification")] = i18n("Certifications");
+  return hash;
+}
+
 Tellico::Fetch::ConfigWidget* IMDBFetcher::configWidget(QWidget* parent_) const {
   return new IMDBFetcher::ConfigWidget(parent_, this);
 }
@@ -1202,7 +1215,7 @@ IMDBFetcher::ConfigWidget::ConfigWidget(QWidget* parent_, const IMDBFetcher* fet
   l->setRowStretch(++row, 10);
 
   // now add additional fields widget
-  addFieldsWidget(IMDBFetcher::customFields(), fetcher_ ? fetcher_->m_fields : QStringList());
+  addFieldsWidget(IMDBFetcher::allOptionalFields(), fetcher_ ? fetcher_->optionalFields() : QStringList());
 
   if(fetcher_) {
     m_hostEdit->setText(fetcher_->m_host);
@@ -1215,30 +1228,17 @@ IMDBFetcher::ConfigWidget::ConfigWidget(QWidget* parent_, const IMDBFetcher* fet
   }
 }
 
-void IMDBFetcher::ConfigWidget::saveConfig(KConfigGroup& config_) {
+void IMDBFetcher::ConfigWidget::saveConfigHook(KConfigGroup& config_) {
   QString host = m_hostEdit->text().trimmed();
   if(!host.isEmpty()) {
     config_.writeEntry("Host", host);
   }
   config_.writeEntry("Max Cast", m_numCast->value());
   config_.writeEntry("Fetch Images", m_fetchImageCheck->isChecked());
-
-  saveFieldsConfig(config_);
-  slotSetModified(false);
 }
 
 QString IMDBFetcher::ConfigWidget::preferredName() const {
   return IMDBFetcher::defaultName();
 }
 
-//static
-Tellico::StringMap IMDBFetcher::customFields() {
-  StringMap map;
-  map[QLatin1String("imdb")]             = i18n("IMDb Link");
-  map[QLatin1String("imdb-rating")]      = i18n("IMDb Rating");
-  map[QLatin1String("alttitle")]         = i18n("Alternative Titles");
-  map[QLatin1String("allcertification")] = i18n("Certifications");
-  return map;
-}
-
 #include "imdbfetcher.moc"
